@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2008-2012 Bastian Kleineidam
+# Copyright (C) 2008-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -234,7 +234,7 @@ class LinkCheckerMain (QtGui.QMainWindow, Ui_MainWindow):
         """Read user and system configuration file."""
         try:
             self.config.read()
-        except LinkCheckerError, msg:
+        except LinkCheckerError as msg:
             self.config_error = unicode(msg)
 
     def set_config (self):
@@ -268,7 +268,7 @@ class LinkCheckerMain (QtGui.QMainWindow, Ui_MainWindow):
             confvalue = self.config[key]
             if isinstance(confvalue, list):
                 # make copy of lists to avoid unwanted inserted items
-                confvalue = list(confvalue)
+                confvalue = confvalue[:]
             self.config_backup[key] = confvalue
         if value is not None:
             self.config[key] = value
@@ -276,7 +276,11 @@ class LinkCheckerMain (QtGui.QMainWindow, Ui_MainWindow):
     def restore_config (self):
         """Restore config from backup."""
         for key in self.config_backup:
-            self.config[key] = self.config_backup[key]
+            confvalue = self.config_backup[key]
+            if isinstance(confvalue, list):
+                # make copy of lists to avoid unwanted inserted items
+                confvalue = confvalue[:]
+            self.config[key] = confvalue
 
     def get_status (self):
         """Return current application status."""
@@ -574,13 +578,14 @@ Version 2 or later.
         url = mime.urls()[0]
         if url.scheme() != 'file':
             return event.ignore()
-        if not url.path().toLower().endsWith(ProjectExt):
-            return event.ignore()
         event.accept()
 
     def handleDropEvent(self, event):
-        """Handle drop event."""
+        """Handle drop event. Detects and loads project files, else sets the URL."""
         mime = event.mimeData()
         url = mime.urls()[0]
-        filename = unicode(url.toLocalFile())
-        loadproject(self, filename)
+        if url.path().toLower().endsWith(ProjectExt):
+            filename = unicode(url.toLocalFile())
+            loadproject(self, filename)
+        else:
+            self.urlinput.setText(url.toString())
