@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2012 Bastian Kleineidam
+# Copyright (C) 2004-2013 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,8 +39,9 @@ class TestHttpMisc (HttpServerTest):
             u"valid",
             u"url http://www.example.org/",
             u"cache key http://www.example.org/",
-            u"real url http://www.iana.org/domains/example/",
+            u"real url http://www.iana.org/domains/example",
             u"info Redirected to `http://www.iana.org/domains/example/'.",
+            u"info Redirected to `http://www.iana.org/domains/example'.",
             u"valid",
         ]
         self.direct(url, resultlines, recursionlevel=1)
